--
-- 4.2.2 TO 4.3.0 --
--

-- OpenID Support
ALTER TABLE ethereal.Puppeteer ADD PuppeteerOpenID      VARCHAR(255);

CREATE UNIQUE INDEX idxPuppeteer_OpenID ON ethereal.Puppeteer
(
  PuppeteerOpenID
);

CREATE TABLE ethereal.OpenID (
  OpenIDServer         VARCHAR(255)  NOT NULL,
  OpenIDType           VARCHAR(9)    NOT NULL DEFAULT 'HMAC-SHA1',
  OpenIDAssociate      VARCHAR(255)  NOT NULL, 
  OpenIDExpires        TIMESTAMP     NOT NULL,
  OpenIDMac            VARCHAR(255)  NOT NULL,
  OpenIDState          VARCHAR(5)    NOT NULL DEFAULT 'smart',
  CONSTRAINT pkOpenID                PRIMARY KEY (OpenIDServer, OpenIDType, OpenIDAssociate),
  CONSTRAINT enumOpenIDState         CHECK (OpenIDState IN ('dumb','smart'))
) WITHOUT OIDS;

CREATE OR REPLACE FUNCTION ethereal.addInterval(interval) RETURNS TIMESTAMP WITHOUT TIME ZONE AS'
  SELECT LOCALTIMESTAMP + $1
 ' LANGUAGE SQL IMMUTABLE STRICT;

DELETE FROM ethereal.Tag WHERE TagName='TmplAuth';
DELETE FROM ethereal.Tag WHERE TagType='system' AND TagName='TmplUser';
DELETE FROM ethereal.Tag WHERE TagType='user' AND TagName='TmplRegConf';



-- Legacy features
ALTER TABLE ethereal.Puppeteer ADD PuppeteerLegacy      VARCHAR(7);
UPDATE ethereal.Puppeteer SET PuppeteerLegacy='default';
ALTER TABLE ethereal.Puppeteer ALTER COLUMN PuppeteerLegacy SET NOT NULL;
ALTER TABLE ethereal.Puppeteer ALTER COLUMN PuppeteerLegacy SET DEFAULT 'default';
ALTER TABLE ethereal.Puppeteer ADD CONSTRAINT enumPuppeteerLegacy CHECK (PuppeteerLegacy IN ('default','legacy'));

-- Additional tags
ALTER TABLE ethereal.Tag DROP CONSTRAINT enumTagType;
ALTER TABLE ethereal.Tag ADD  CONSTRAINT enumTagType CHECK (TagType IN ('admin','board','bio','configuration','contrib','faq','gallery','gummy','login','mail','menu','poll','portal','realm','system','template','user','vanity','vcodes'));


-- Fix for offline realms
ALTER TABLE ethereal.Post DROP CONSTRAINT enumPostClass;
ALTER TABLE ethereal.Post ADD CONSTRAINT enumPostClass  CHECK (PostClass IN ('banner','dice','duplicate','general','play','private','special','system','offline'));


-- Biographical table
UPDATE ethereal.Tag SET TagName='LnkIntGallery', TagType='system' WHERE TagName='LnkGallery' AND TagType='bio';
UPDATE ethereal.Tag SET TagName='LnkExtMail', TagType='system' WHERE TagName='LnkMail' AND TagType='bio';

-- Board table
UPDATE ethereal.Tag SET TagName='LnkIntBio', TagType='system' WHERE TagName='LnkBio' AND TagType='board';
UPDATE ethereal.Tag SET TagName='LnkIntBoard', TagType='system' WHERE TagName='LnkBoard' AND TagType='board';

-- Contributor table
UPDATE ethereal.Tag SET TagName='LnkIntSetHome', TagType='system' WHERE TagName='LnkHomepage' AND TagType='contrib';
UPDATE ethereal.Tag SET TagName='LnkIntSetGallery', TagType='system' WHERE TagName='LnkManage' AND TagType='contrib';
UPDATE ethereal.Tag SET TagName='SetHomeRoot', TagType='system' WHERE TagName='SetHomeRoot' AND TagType='contrib';
UPDATE ethereal.Tag SET TagName='SetHomeLink', TagType='system' WHERE TagName='SetHomeUrl' AND TagType='contrib';
UPDATE ethereal.Tag SET TagName='SetGalleryRoot', TagType='system' WHERE TagName='SetRoot' AND TagType='contrib';
UPDATE ethereal.Tag SET TagName='SetGalleryLink', TagType='system' WHERE TagName='SetScript' AND TagType='contrib';
DELETE FROM ethereal.Tag WHERE TagName IN ('LnkGallery','LnkView') AND TagType='contrib';

-- Portal
UPDATE ethereal.Tag SET TagName='LnkIntForum', TagType='system' WHERE TagName='LnkForum' AND TagType='portal';
UPDATE ethereal.Tag SET TagName='LnkIntNews', TagType='system' WHERE TagName='LnkNews' AND TagType='portal';
UPDATE ethereal.Tag SET TagName='LnkExtRealm', TagType='system' WHERE TagName='LnkQuickLink' AND TagType='portal';
DELETE FROM ethereal.Tag WHERE TagName IN ('LnkBoard','LnkBio') AND TagType='portal';

-- Realm
UPDATE ethereal.Tag SET TagName='LnkIntOffline', TagType='system' WHERE TagName='LnkOffline' AND TagType='realm';
UPDATE ethereal.Tag SET TagName='LnkIntRealm', TagType='system' WHERE TagName='LnkRealm' AND TagType='realm';
DELETE FROM ethereal.Tag WHERE TagName IN ('LnkBoard','LnkBio','LnkIgnore','LnkMail','LnkPortal','LnkPuppet') AND TagType='realm';

- Poll
UPDATE ethereal.Tag SET TagName='LnkExtVote', TagType='system' WHERE TagName='LnkVote' AND TagType='poll';

-- User
UPDATE ethereal.Tag SET TagName='LnkIntPortal', TagType='system' WHERE TagName='LnkPortal' AND TagType='user';
UPDATE ethereal.Tag SET TagName='LnkExtVanity', TagType='system' WHERE TagName='LnkVanity' AND TagType='user';

-- Vanity
UPDATE ethereal.Tag SET TagName='LnkIntVanity', TagType='system' WHERE TagName='LnkVanity' AND TagType='vanity';
UPDATE ethereal.Tag SET TagName='LnkIntMail', TagType='system' WHERE TagName='LnkMail' AND TagType='vanity';
DELETE FROM ethereal.Tag WHERE TagName IN ('LnkBio') AND TagType='vanity';

-- FAQ
UPDATE ethereal.Tag SET TagName='LnkExtHelp', TagType='system' WHERE TagName='LnkFAQ' AND TagType='faq';

-- Cleanups
DELETE FROM ethereal.Tag WHERE TagType='configuration' AND TagName IN ('TagListButtons');
DELETE FROM ethereal.Tag WHERE TagType='contrib' AND TagName IN ('LnkGallery','LnkView');
DELETE FROM ethereal.Tag WHERE TagType='gallery' AND TagName IN ('LnkBase','LnkBio','LnkGallery','SetRoot','SetScript');
DELETE FROM ethereal.Tag WHERE TagType='login' AND TagName IN ('LnkPortal');
DELETE FROM ethereal.Tag WHERE TagType='mail' AND TagName IN ('LnkBio','TxtMailInvalid');
DELETE FROM ethereal.Tag WHERE TagType='portal' AND TagName IN ('TmplAdminSect','TmplSuperSect','TmplVerifiedSect');
DELETE FROM ethereal.Tag WHERE TagType='realm' AND TagName IN ('TagLinkSystem','TagTitleWho','TagTotal');
DELETE FROM ethereal.Tag WHERE TagType='user' AND TagName IN ('TagPupRoomPreview','TmplPupImportList');
DELETE FROM ethereal.Tag WHERE TagType='vanity' AND TagName IN ('MsgErrorEmpty','TmplSocialError','TmplSocialWarn');


CREATE TABLE ethereal.Watch (
  PuppetName           VARCHAR(30)   NOT NULL,
  PuppetPool           VARCHAR(30)   NOT NULL,
  RealmName            VARCHAR(30)   NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  CONSTRAINT pkWatch                 PRIMARY KEY (PuppetName, PuppetPool, RealmName, PuppeteerLogin),
  CONSTRAINT fkWatchPuppet FOREIGN KEY (PuppetName, PuppetPool)
    REFERENCES ethereal.Puppet (PuppetName, PuppetPool)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkWatchPuppeteer FOREIGN KEY (PuppeteerLogin)
    REFERENCES ethereal.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkWatchRealm FOREIGN KEY (RealmName)
    REFERENCES ethereal.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;


